# locloc

[![PyPI version]](https://badge.fury.io/py/locloc)
[![Maintainability]](https://codeclimate.com/github/eggplants/locloc/maintainability)
[![pre-commit.ci status]](https://results.pre-commit.ci/latest/github/eggplants/locloc/master)
[![Test Coverage]](https://codeclimate.com/github/eggplants/locloc/test_coverage)
[![Test]](https://github.com/eggplants/locloc/actions/workflows/test.yml)

[![ghcr latest] ![ghcr size]](https://github.com/eggplants/locloc/pkgs/container/locloc)

[PyPI version]: https://badge.fury.io/py/locloc.svg
[Maintainability]: https://api.codeclimate.com/v1/badges/2a065d7fbf4b174b0f94/maintainability
[pre-commit.ci status]: https://results.pre-commit.ci/badge/github/eggplants/locloc/master.svg
[Test Coverage]: https://api.codeclimate.com/v1/badges/2a065d7fbf4b174b0f94/test_coverage
[Test]: https://github.com/eggplants/locloc/actions/workflows/test.yml/badge.svg
[ghcr latest]: https://ghcr-badge.deta.dev/eggplants/locloc/latest_tag?trim=major&label=latest
[ghcr size]: https://ghcr-badge.deta.dev/eggplants/locloc/size

Online LOC counter

## Example

<https://locloc.onrender.com/svg?url=https://github.com/eggplants/locloc>

![locloc for locloc](https://locloc.onrender.com/svg?url=https%3A%2F%2Fgithub.com%2Feggplants%2Flocloc)

## Deployment

[![Website]](https://locloc.onrender.com)

[Website]: https://img.shields.io/website?label=locloc.onrender.com&url=https%3A%2F%2Flocloc.onrender.com

## Related work

- <s><https://locfetch.app/></s> (closed)

  - ref: <https://zenn.dev/kyoheiu/articles/3f01fef8afe2c9>

- <https://codetabs.com/count-loc/count-loc-online.html>
  - source: <https://github.com/jolav/codetabs>
